#
# spec file for package libgnomesu
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libgnomesu
Version:        2.0.0
Release:        7.4
Summary:        GNOME su Library
License:        LGPL-2.1+
Group:          System/GUI/GNOME
Url:            https://github.com/openSUSE/libgnomesu
Source:         %{name}-%{version}.tar.bz2
Source1:        gnomesu-pam.pamd
# Patch: Avoid patches if possible! Update openSUSE upstream instead.
BuildRequires:  fdupes
BuildRequires:  gtk3-devel
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pam-devel
BuildRequires:  translation-update-upstream
PreReq:         permissions
Requires:       gsettings-desktop-schemas
Requires:       pam
Recommends:     %{name}-lang = %{version}
# Ensure that gnomesu always gets installed
Supplements:    packageand(xdg-utils:gnome-session)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Libgnomesu is a library for providing superuser privileges to GNOME
applications. It supports sudo, consolehelper, PAM, and su.

%package -n libgnomesu0
Summary:        GNOME su Library
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n libgnomesu0
Libgnomesu is a library for providing superuser privileges to GNOME
applications. It supports sudo, consolehelper, PAM, and su.

%package devel
Summary:        Development files for libgnomesu
Group:          Development/Libraries/GNOME
Requires:       %{name} = %{version}

%description devel
This package contains all files needed to develop with libgnomesu.

%lang_package
%prep
%setup -q
cp -a %{S:1} pam-backend/gnomesu-pam
# Upstream is dead, libgnomesu.po in LCN includes strings in our patches:
translation-update-upstream

%build
export SUID_CFLAGS="-fPIE"
export SUID_LDFLAGS="-pie"
%configure\
	--libexecdir=%{_libexecdir}/%{name}\
	--disable-setuid-error
make %{?jobs:-j%jobs}

%install
mkdir -p %{buildroot}%{_prefix}/lib/%{name}
%makeinstall
%{__rm} %{buildroot}%{_libdir}/*.la
%find_lang libgnomesu-1.0
mkdir -p %{buildroot}%{_docdir}/%{name}
cp AUTHORS README NEWS ChangeLog doc/api.html doc/libgnomesu.css %{buildroot}%{_docdir}/%{name}
# We want only PAM backend.
rm -f %{buildroot}%{_prefix}/lib/%{name}/gnomesu-backend
%fdupes %{buildroot}

%clean
rm -rf %{buildroot}

%post
%set_permissions %{_libexecdir}/%{name}/gnomesu-pam-backend

%verifyscript
%verify_permissions -e %{_libexecdir}/%{name}/gnomesu-pam-backend

%post -n libgnomesu0 -p /sbin/ldconfig

%postun -n libgnomesu0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc %dir %{_defaultdocdir}/%{name}
%doc %{_defaultdocdir}/%{name}/AUTHORS
%doc %{_defaultdocdir}/%{name}/README
%doc %{_defaultdocdir}/%{name}/NEWS
%doc %{_defaultdocdir}/%{name}/ChangeLog
%{_bindir}/gnomesu
%dir %{_prefix}/lib/%{name}
#%%attr (6755,root,root) %%{_prefix}/lib/%%{name}/gnomesu-backend
#%%attr (6755,root,root) %%{_prefix}/lib/%%{name}/gnomesu-pam-backend
# NOTE: Original package has 6755.
# We have only 4755 and for easy and secure profile.
%verify (not mode) %attr (4755,root,root) %{_libexecdir}/%{name}/gnomesu-pam-backend
%config %{_sysconfdir}/pam.d/gnomesu-pam

%files -n libgnomesu0
%defattr (-, root, root)
%{_libdir}/libgnomesu.so.*

%files lang -f libgnomesu-1.0.lang

%files devel
%defattr(-,root,root)
%doc %{_docdir}/%{name}/api.html
%doc %{_docdir}/%{name}/libgnomesu.css
%{_includedir}/libgnomesu-1.0
%{_libdir}/libgnomesu.so
%{_libdir}/pkgconfig/libgnomesu-1.0.pc

%changelog
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
- Drop libgnomesu-exit-with-parent.patch: now included in tarball.
* Thu Sep 10 2015 sbrabec@suse.com
- Include lost SLE11 fix from hpj@novell.com:
  * Add libgnomesu-exit-with-parent.patch, to make child process
    exit if parent does. Part of bnc#578284.
* Thu Sep 10 2015 sbrabec@suse.com
- Update to version 2.0.0 maintained by openSUSE:
  * Obsolete all SUSE patches
    (libgnomesu-better-pam-handling.patch,
    libgnomesu-bnc440970-safe-path.patch
    libgnomesu-drop-libgnomeui.patch, libgnomesu-gtk3.patch
    libgnomesu-check-setuid-retval.patch,
    libgnomesu-ia64-crash.patch, libgnomesu-i18n.patch,
    libgnomesu-libtool.patch, libgnomesu-makefile.patch,
    libgnomesu-modernize.patch, libgnomesu-no-gconf.patch,
    libgnomesu-no-manual-memory-cleaning.patch,
    libgnomesu-remove-prior-cookie.patch,
    libgnomesu-reorder-pam-init.patch,
    libgnomesu-set-xdg_runtime_dir.patch,
    libgnomesu-startup-notification.patch
    libgnomesu-suid_flags.patch, libgnomesu-unsetenv.patch,
    libgnomesu-use-pam_xauth.patch,
    libgnomesu-1.0.0-spin-mainloop.patch,
    libgnomesu-1.0.0-xauth-nolookup.patch, libgnomesu-64bit.patch)
  * Include lost SLE11 fix from hpj@novell.com:
    Add patch to make child process exit if parent does. Part of
    bnc#578284.
  * Translation updates.
* Fri Feb  6 2015 dimstar@opensuse.org
- Add libgnomesu-set-xdg_runtime_dir.patch: explicitly set
  XDG_RUNTIME_DIR for the new user (boo#908167).
* Thu Feb  5 2015 coolo@suse.com
- Use rm -f to avoid rm asking back with strict umasks.
* Sat Sep 21 2013 dimstar@opensuse.org
- Change RPM Group of shared library package to System/Libraries.
* Thu Mar  7 2013 dimstar@opensuse.org
- Enhance libgnomesu-gtk3.patch: add #undef GTK_DISABLE_DEPRECATED
  in order to allow usage of deprecated symbols (e.g. GTK_TABLE).
* Thu Sep  6 2012 tittiatcoke@gmail.com
- Add a Supplements for gnome-session and xdg-utils, to ensure that
  gnomesu is automatically installed when the user installs GNOME.
  Until now, we were relying on the patterns.
* Fri Feb 24 2012 vuntz@opensuse.org
- Add libgnomesu-suid_flags.patch: respect SUID_CFLAGS/SUID_LDFLAGS
  when building the suid binary gnomesu-pam-backend.
- Set SUID_CFLAGS to -fPIE and SUID_LDFLAGS to -pie in %%build. This
  fixes bnc#743139.
* Sun Nov 13 2011 coolo@suse.com
- add libtool as explicit BuildRequires to avoid implicit
  dependency from prjconf.
* Tue Jul 19 2011 vuntz@opensuse.org
- Add libgnomesu-no-gconf.patch: use GSettings instead of gconf to
  find the preferred terminal; this is needed for GNOME 3
  integration.
- Add libgnomesu-gtk3.patch: port to GTK+ 3.
- Change gtk2-devel BuildRequires to gtk3-devel.
- Remove now unneeded gconf2-devel BuildRequires.
- Add gsettings-desktop-schemas Requires, since the use of
  GSettings require the schema to be installed.
- Remove explicit Requires for glib2-devel and gtk2-devel in devel
  subpackage: if needed, they will automatically be added the
  pkgconfig() way.
* Mon May 30 2011 vuntz@opensuse.org
- Add libgnomesu-check-setuid-retval.patch: really handle return
  value of the setuid() call, to avoid a root exploit if it fails
  because of rlimits. Fix bnc#695627 and CVE-2011-1946.
* Thu May  5 2011 vuntz@opensuse.org
- Use %%{_libexecdir} instead of %%{_prefix}/lib.
- Do not use %%run_permissions in %%post of libgnomesu0 since there
  is no file with specific permissions there. Instead use the more
  specific %%set_permissions in %%post of the main package.
- Note that the permissions PreReq and the %%verifyscript were for
  the main package already.
* Tue Feb 15 2011 vuntz@opensuse.org
- Add libgnomesu-use-pam_xauth.patch: with the pam backend, we
  should stop playing with xauth ourselves and let pam_xauth handle
  this. It turns out it's already configured to do so in
  gnomesu-pam.pamd, but we're hiding things to it.
- Add libgnomesu-reorder-pam-init.patch: in the pam backend, we
  want to initialize everything in the right order, and we use the
  coreutils/su code as reference for this.
* Wed Jan 26 2011 vuntz@opensuse.org
- Update libgnomesu-modernize.patch: define an icon for the
  Continue button. It will only be shown if user configures the
  desktop to show icons for buttons. Fix bnc#639203.
* Tue Aug 31 2010 aj@suse.de
- Recommend instead of require lang package since it's not mandatory.
* Sat Aug  7 2010 vuntz@opensuse.org
- Update libgnomesu-modernize.patch to fix build with recent GTK+.
* Thu Jun  3 2010 vuntz@opensuse.org
- Add libgnomesu-no-manual-memory-cleaning.patch to fix some bad
  code that tries to remove passwords from memory the wrong way.
  GTK+ already does this for us. As a side-effect, this fixes
  bnc#351917.
* Wed Apr 14 2010 sbrabec@suse.cz
- Fixed translatability (bnc#582085).
- Add libgnomesu-remove-prior-cookie.patch (bnc#477638) from SLE11
  (hpj@novell.com).
* Sat Mar 13 2010 dimstar@opensuse.org
- Modernize libgnomesu-modernize.patch not to use deprecated
  GTK symbols.
* Wed Mar 10 2010 sbrabec@suse.cz
- Upstream of libgnomesu is dead. Move translation to a separate
  LCN project and migrate from gnome-patch-translation to
  translation-update-upstream (bnc#562162#c2).
* Thu Dec  3 2009 vuntz@opensuse.org
- Rebase libgnomesu-bnc440970-safe-path.patch to apply without
  fuzz.
* Mon Sep 28 2009 vuntz@opensuse.org
- Use gnome-patch-translation for new strings added by patch. Part
  of bnc#541653.
- Use spec-cleaner to clean the spec file.
* Wed Jul 15 2009 vuntz@novell.com
- Add libgnomesu-bnc440970-safe-path.patch to fix bnc#440970:
  instead of resetting PATH to a default value that we can't get
  right, just remove the unsafe values.
* Wed May 20 2009 vuntz@novell.com
- Drop useless update-polish-patch.sh script.
* Wed May 13 2009 vuntz@novell.com
- Tag patches.
- Remove AutoReqProv: it's default now.
* Thu Apr 30 2009 vuntz@novell.com
- Remove .la files.
* Thu Mar 19 2009 vuntz@novell.com
- Make gnomesu handle "gnomesu -- gnomesu -- ls". We used to end up
  with a leading "--" in a command we were spawning, which doesn't
  work. This is an update to libgnomesu-drop-libgnomeui.patch,
  which was wrong for this.
  Fix bnc#486644.
* Wed Feb  4 2009 vuntz@novell.com
- Add libgnomesu-drop-libgnomeui.patch to drop libgnomeui
  dependency.
- Remove BuildRequires on libgnomeui and replace it with
  BuildRequires on gconf2-devel and gtk2-devel.
* Tue Feb  3 2009 schwab@suse.de
- Remove broken casts:
  Add libgnomesu-ia64-crash.patch to fix crash on ia64 because of
  broken casts.
* Sat Jan 31 2009 vuntz@novell.com
- Add libgnomesu-better-pam-handling.patch to handle PAM errors
  during authentication better, so the user has a better feedback.
  Hopefully fixes bnc#430883.
* Sat Jan 31 2009 vuntz@novell.com
- Add libgnomesu-startup-notification.patch to forward the startup
  notification information when there's no need for authentication
  dialog. The main use case is the yast2 control center, where we
  are already root. Fix bnc#458651.
- Use sr@latin instead of sr@Latn.
- Remove checks for old versions of openSUSE.
* Mon Jan 12 2009 mauro@suse.de
- Translations update.
* Sun Dec 28 2008 abockover@novell.com
- Patch to "modernize" gnomesu in the image of PolicyKit-gnome
  * Fix bnc#462073
  * GNOME HIG compliant
  * Uses the GTK icon theme
* Sat Dec  6 2008 mauro@suse.de
- Translation update.
* Thu Nov  6 2008 vuntz@novell.com
- Add libgnomesu-unsetenv.patch to unset the
  DBUS_SESSION_BUS_ADDRESS environment variable. Fix bnc#428963.
* Fri Oct 10 2008 hpj@novell.com
- Remove libgnomesu-1.0.0-ensure-xauthority-env.patch. It breaks
  with the xauth location used by the new gdm.
* Fri Oct  3 2008 vuntz@novell.com
- Run intltoolize so that the translations get installed. It seems
  the new intltool broke this.
* Wed Oct  3 2007 maw@suse.de
- Split out a libgnomesu0 shared library package.
* Fri Sep 28 2007 maw@suse.de
- Add libgnomesu-1.0.so-polish as a source file and copy
  it to the po/ directory (#302300).
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage
- s#%%run_ldconfig#/sbin/ldconfig/ in %%post and %%postun.
* Wed Mar 21 2007 jhargadon@suse.de
- added a patch to fix the library path for 64 bit packages.
* Tue Jan  2 2007 sbrabec@suse.cz
- Fixed invalid Makefile expansion.
* Fri Dec 22 2006 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Tue Jun 20 2006 sbrabec@suse.cz
- Updated translations from upstream (179651#c15).
* Fri May 26 2006 zsu@suse.de
- bugzilla #169082. Call _() to translate label string "_Password:"
* Thu May 18 2006 ro@suse.de
- add setuid bit to gnomesu-pam-backend in level secure (#175616)
* Thu May  4 2006 danw@suse.de
- stick the command label in a scrolledwindow in case it's really
  really long. #161044
* Thu May  4 2006 hpj@suse.de
- Add patch to ensure that XAUTHORITY is always set in the child
  environment. Fixes Novell bug #172494.
* Fri Mar 31 2006 danw@suse.de
- Don't mark the error text as "selectable", since that will make
  it focusable as well and mess up the tab order. #162600
* Mon Mar 20 2006 hpj@suse.de
- Add patch to make it spin the main loop while waiting for the
  child to exit. Fixes Novell bug #156445.
* Mon Jan 30 2006 ro@suse.de
- reduce BuildRequires as far as possible
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 17 2005 hpj@suse.de
- Fixed the nlist/nmerge patch to actually work (#119600).
* Fri Oct 14 2005 hpj@suse.de
- Run xauth nlist/nmerge instead of list, prevents DNS lookups
  (#119600).
* Tue Sep 20 2005 sbrabec@suse.cz
- Removed references to build directory in installed .la files.
- Fixed devel dependencies.
* Thu Jun  9 2005 sbrabec@suse.cz
- Updated to version 1.0.0.
- Set permissions properly (#75823).
- Removed crypt backend (#75823).
* Mon May 16 2005 sbrabec@suse.cz
- Updated to version 0.9.7.
* Thu May 12 2005 sbrabec@suse.cz
- Provide and obsolete xsu (#75823).
- Fixed crash on x86_64.
- Build and install PAM backend.
- Fixed backend permissions.
* Fri Apr 15 2005 sbrabec@suse.cz
- Simplified neededforbuild.
- Added devel documentation.
* Tue Feb  8 2005 hhetter@suse.de
- package without setuid bits for now (#50436)
* Thu Feb  3 2005 hhetter@suse.de
- initial SUSE package
